``pygcam.XMLFile``
============================

This module contains the ``XMLFile`` class, which provides support for
:doc:`conditional-xml`, XML schema validation, as well as defining the
`McsValues` class, a subclass of ``XMLFile``.


API
---

.. automodule:: pygcam.XMLFile
   :members:
